<?php

function figero_widget_myRecentPosts_init() {

    function widget_myRecentPosts($args) {

        // "$args is an array of strings that help widgets to conform to
        // the active theme: before_widget, before_title, after_widget,
        // and after_title are the array keys." - These are set up by the theme
        extract($args);
        // These are our own options
        $options = get_option('widget_myRecentPosts');
        $title = $options['title'];  // Title in sidebar for widget
        $show = $options['show'];  // # of Posts we are showing
        $excerpt = $options['excerpt'];  // Showing the excerpt or not
        $exclude = $options['exclude'];  // Categories to exclude
        if ($show < 1)
            $show = 1;
        if ($exclude == "")
            $exclude = "0";

        // Output
        echo $before_widget . $before_title . $title . $after_title;
        // GET POSTS
        global $wpdb;
        $sql = ("SELECT * FROM $wpdb->posts WHERE post_status = 'publish' AND
                post_type = 'post' AND ID IN (SELECT DISTINCT post_parent FROM $wpdb->posts WHERE post_parent > 0
                AND
                post_type = 'attachment'
                AND
                post_mime_type IN ('image/jpeg', 'image/png')
                )
                ORDER BY post_date DESC LIMIT $show
                ");
        $posts = $wpdb->get_results($sql);

        // start list
        echo '<ul class="recent_post">';
        // were there any posts found?
        if (!empty($posts)) {
            // posts were found, loop through them
            foreach ($posts as $post) {

                // format a date for the posts
                $post->post_date = date('M j, Y', strtotime($post->post_date));

                // if we want to display an excerpt, get it/generate it if no excerpt found
                if ($excerpt) {
                    if (empty($post->post_excerpt)) {
                        $post->post_excerpt = explode(" ", strrev(substr(strip_tags($post->post_content), 0, 100)), 2);
                        if (isset($post->post_excerpt[1])) {
                            $post->post_excerpt = strrev($post->post_excerpt[1]);
                            $post->post_excerpt.= " [...]";
                        }
                    }
                }
                $homeLink = get_template_directory_uri();
                $first_img = '';
                ob_start();
                ob_end_clean();
                $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
                if (isset($matches [1] [0])) {
                    $first_img = $matches [1] [0];
                }
                if (empty($first_img)) { //Defines a default image
                    //$first_img = "/images/default.jpg";
                }
                //output to screen
                echo '<li>';
                echo '<a class="post" rel="bookmark" href="' . get_permalink($post->ID) . '"><img src="' . $first_img . '"/>';
                $tit = $post->post_title;
                echo substr($tit, 0, 25);
                if (strlen($tit) > 10)
                    echo "&rarr;";
                echo '</li>';
            }
        } else
            echo "<li>No recent Posts</li>";
        // end list
        echo '</ul>';

        // echo widget closing tag
        echo $after_widget;
    }

    // Settings form
    function figero_widget_myRecentPosts_control() {
        // Get options
        $options = get_option('widget_myRecentPosts');
        // options exist? if not set defaults
        if (!is_array($options))
            $options = array('title' => 'Recent Posts', 'show' => '5', 'excerpt' => '1', 'exclude' => '');

        // form posted?
        if (isset($_POST['myRecentPosts-submit'])) {
            // Remember to sanitize and format use input appropriately.
            $options['title'] = strip_tags(stripslashes($_POST['myRecentPosts-title']));
            $options['show'] = strip_tags(stripslashes($_POST['myRecentPosts-show']));
            $options['excerpt'] = strip_tags(stripslashes($_POST['myRecentPosts-excerpt']));
            $options['exclude'] = strip_tags(stripslashes($_POST['myRecentPosts-exclude']));
            update_option('widget_myRecentPosts', $options);
        }
        // Get options for form fields to show
        $title = htmlspecialchars($options['title'], ENT_QUOTES);
        $show = htmlspecialchars($options['show'], ENT_QUOTES);
        $excerpt = htmlspecialchars($options['excerpt'], ENT_QUOTES);
        $exclude = htmlspecialchars($options['exclude'], ENT_QUOTES);

        // The form fields
        echo '<p><label for="myRecentPosts-title">' . __('Title:', 'figero') . ' </label><input style="width: 100%;" id="myRecentPosts-title" name="myRecentPosts-title" type="text" value="' . $title . '" /></p>';
        echo '<p><label for="myRecentPosts-show">' . __('Show:', 'figero') . ' </label><input style="width: 100%;" id="myRecentPosts-show" name="myRecentPosts-show" type="text" value="' . $show . '" /></p>';
        echo '<input id="myRecentPosts-excerpt" name="myRecentPosts-excerpt" type="hidden" value="' . $excerpt . '" />';
        echo '<input id="myRecentPosts-exclude" name="myRecentPosts-exclude" type="hidden" value="' . $exclude . '" />';
        echo '<input type="hidden" id="myRecentPosts-submit" name="myRecentPosts-submit" value="1" />';
    }

    // Register widget for use
    wp_register_sidebar_widget('sidebar_wdgt_rgstr', __('Recent Posts With Thumbnail', 'figero'), 'widget_myRecentPosts');
    // Register settings for use, 300x100 pixel form
    wp_register_widget_control('sidebar_wdgt_rgstr', __('Recent Posts With Thumbnail', 'figero'), 'figero_widget_myRecentPosts_control', 260, 200);
}

// Run code and init
add_action('widgets_init', 'figero_widget_myRecentPosts_init');
?>
